@@ -5,13 +5,13 @@ import json
 import os
 import requests
 import logging
-import re
 import threading
 from .webhook import get, get_list
 from .parser import parse
 from pathlib import Path
+from distutils.version import LooseVersion
 
-__DEFAULT_FILE__ = str(Path.home()) + '/.github_release_notifier/versions'
+__DEFAULT_FILE__ = os.getenv('GRN_VERSIONS_FILE', str(Path.home()) + '/.github_release_notifier/versions')
 
 
 def version_compare(version1: str, version2: str) -> int:
@@ -26,7 +26,7 @@ def _call_webhook(webhook: str, entry: str, logger: logging.Logger) -> None:
     try:
         requests.post(webhook, json=entry)
     except requests.exceptions.RequestException:
-        logger.error("Error occured : %s" % (sys.exc_info()[0]))
+        logger.error("Error occurred : %s" % (sys.exc_info()[0]))
 
 
 def run(file: str = __DEFAULT_FILE__) -> dict:
@@ -34,14 +34,24 @@ def run(file: str = __DEFAULT_FILE__) -> dict:
     logger = logging.getLogger(__name__)
     updated = {}
     for package in get_list():
-        for entry in parse(package):
-            if version_compare(entry['version'], get_version(package)) > 0:
-                database = _get_database(file)
-                database[package] = entry['version']
-                _set_database(database, file)
-                updated[package] = entry['version']
-                for webhook in get(package):
-                    threading.Thread(target=_call_webhook, args=(webhook, entry, logger,)).start()
+        try:
+            for entry in parse(package):
+                try:
+                    condition = LooseVersion(str(entry['version'])) > LooseVersion(str(get_version(package)))
+                except TypeError as e:
+                    condition = version_compare(str(entry['version']), str(get_version(package))) > 0
+                if condition:
+                    database = _get_database(file)
+                    database[package] = entry['version']
+                    _set_database(database, file)
+                    updated[package] = entry['version']
+                    for webhook in get(package):
+                        threading.Thread(target=_call_webhook, args=(webhook, entry, logger,)).start()
+        except NameError as e:
+            logger.error("Package removed : %s" % package)
+            database = _get_database(file)
+            del database[package]
+            _set_database(database, file)
     return updated
 
 
